@@ -1,3 +1,3 @@
 from .client import Client, generate_token
-from .models import *
-from .exceptions import *
\ No newline at end of file
+from .Datamodels import *
+from .exceptions import *
